Coverage report

# Coverage report: 97%

Hot-keys on this page

n s m x c change column sorting

Module | statements | missing | excluded | coverage
--- | --- | --- | --- | ---
Total | 1291 | 37 | 18 | 97%
pandalone/components.py | 70 | 1 | 4 | 99%
pandalone/mappings.py | 336 | 3 | 2 | 99%
pandalone/pandata.py | 368 | 24 | 8 | 93%
pandalone/xleash/_capture.py | 187 | 0 | 2 | 100%
pandalone/xleash/_parse.py | 158 | 1 | 0 | 99%
pandalone/xleash/io/__init__.py | 1 | 0 | 0 | 100%
pandalone/xleash/io/backend.py | 171 | 8 | 2 | 95%

No items found using the specified filter.